import { UnpluginOptions } from "unplugin";
import { Options } from "./types";
interface SentryUnpluginFactoryOptions {
    releaseInjectionPlugin: (injectionCode: string) => UnpluginOptions;
    debugIdInjectionPlugin: () => UnpluginOptions;
    debugIdUploadPlugin: (upload: (buildArtifacts: string[]) => Promise<void>) => UnpluginOptions;
}
/**
 * The sentry bundler plugin concerns itself with two things:
 * - Release injection
 * - Sourcemaps upload
 *
 * Release injection:
 * Per default the sentry bundler plugin will inject a global `SENTRY_RELEASE` into each JavaScript/TypeScript module
 * that is part of the bundle. On a technical level this is done by appending an import (`import "sentry-release-injector;"`)
 * to all entrypoint files of the user code (see `transformInclude` and `transform` hooks). This import is then resolved
 * by the sentry plugin to a virtual module that sets the global variable (see `resolveId` and `load` hooks).
 * If a user wants to inject the release into a particular set of modules they can use the `releaseInjectionTargets` option.
 *
 * Source maps upload:
 *
 * The sentry bundler plugin will also take care of uploading source maps to Sentry. This
 * is all done in the `writeBundle` hook. In this hook the sentry plugin will execute the
 * release creation pipeline:
 *
 * 1. Create a new release
 * 2. Delete already uploaded artifacts for this release (if `cleanArtifacts` is enabled)
 * 3. Upload sourcemaps based on `include` and source-map-specific options
 * 4. Associate a range of commits with the release (if `setCommits` is specified)
 * 5. Finalize the release (unless `finalize` is disabled)
 * 6. Add deploy information to the release (if `deploy` is specified)
 *
 * This release creation pipeline relies on Sentry CLI to execute the different steps.
 */
export declare function sentryUnpluginFactory({ releaseInjectionPlugin, debugIdInjectionPlugin, debugIdUploadPlugin, }: SentryUnpluginFactoryOptions): import("unplugin").UnpluginInstance<Options, true>;
export declare function getBuildInformation(): {
    deps: string[];
    depsVersions: Record<string, number>;
    nodeVersion: number | undefined;
};
/**
 * Determines whether the Sentry CLI binary is in its expected location.
 * This function is useful since `@sentry/cli` installs the binary via a post-install
 * script and post-install scripts may not always run. E.g. with `npm i --ignore-scripts`.
 */
export declare function sentryCliBinaryExists(): boolean;
export declare function createRollupReleaseInjectionHooks(injectionCode: string): {
    resolveId(id: string): {
        id: string;
        external: boolean;
        moduleSideEffects: boolean;
    } | null;
    load(id: string): string | null;
    transform(code: string, id: string): {
        code: string;
        map: import("magic-string").SourceMap;
    } | null;
};
export declare function createRollupDebugIdInjectionHooks(): {
    renderChunk(code: string, chunk: {
        fileName: string;
    }): {
        code: string;
        map: import("magic-string").SourceMap;
    } | null;
};
export declare function createRollupDebugIdUploadHooks(upload: (buildArtifacts: string[]) => Promise<void>): {
    writeBundle(outputOptions: {
        dir?: string;
        file?: string;
    }, bundle: {
        [fileName: string]: unknown;
    }): Promise<void>;
};
export declare function getDebugIdSnippet(debugId: string): string;
export type { Options } from "./types";
